aboutsummaryrefslogtreecommitdiff
path: root/benchmarks/CUDA/WP/util4.cu
diff options
context:
space:
mode:
authorTor Aamodt <[email protected]>2010-10-01 08:55:28 -0800
committerTor Aamodt <[email protected]>2010-10-01 08:55:28 -0800
commit11b308e7363e937966b035b4891db32b4eece3bf (patch)
tree50ca4c9ad6f163ac4acb2bf505e64dfebed66947 /benchmarks/CUDA/WP/util4.cu
parentbb820c116764d7a1b8e071137d32b74e7f34dd2f (diff)
integrating recent changes from fermi-test into fermi
(i'll use "fermi" for more disruptive changes to the pipeline model such as updating the MSHRs and getting rid of the warp tracker, ripping out DWF, etc...) [git-p4: depot-paths = "//depot/gpgpu_sim_research/fermi/distribution/": change = 7805]
Diffstat (limited to 'benchmarks/CUDA/WP/util4.cu')
-rw-r--r--benchmarks/CUDA/WP/util4.cu46
1 files changed, 0 insertions, 46 deletions
diff --git a/benchmarks/CUDA/WP/util4.cu b/benchmarks/CUDA/WP/util4.cu
deleted file mode 100644
index 4b629d4..0000000
--- a/benchmarks/CUDA/WP/util4.cu
+++ /dev/null
@@ -1,46 +0,0 @@
-#ifndef PREPASS
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include "cublas.h"
-#endif
-
-__device__ float4 max4 ( const float4 a , const float4 b )
-{
- float4 c ;
- c.x = (a.x>b.x)?a.x:b.x;
- c.y = (a.y>b.y)?a.y:b.y;
- c.z = (a.z>b.z)?a.z:b.z;
- c.w = (a.w>b.w)?a.w:b.w;
- return(c) ;
-}
-__device__ float4 min4 ( const float4 a , const float4 b )
-{
- float4 c ;
- c.x = (a.x<b.x)?a.x:b.x;
- c.y = (a.y<b.y)?a.y:b.y;
- c.z = (a.z<b.z)?a.z:b.z;
- c.w = (a.w<b.w)?a.w:b.w;
- return(c) ;
-}
-
-__device__ float4 log4 ( const float4 a )
-{
- float4 c ;
- c.x = log(a.x) ; c.y = log(a.y) ; c.z = log(a.z) ; c.w = log(a.w) ;
- return(c) ;
-}
-
-__device__ float4 exp4 ( const float4 a )
-{
- float4 c ;
- c.x = exp(a.x) ; c.y = exp(a.y) ; c.z = exp(a.z) ; c.w = exp(a.w) ;
- return(c) ;
-}
-
-__device__ float4 sqrt4 ( const float4 a )
-{
- float4 c ;
- c.x = sqrt(a.x) ; c.y = sqrt(a.y) ; c.z = sqrt(a.z) ; c.w = sqrt(a.w) ;
- return(c) ;
-}